@@ -271,20 +271,30 @@ def worker_main(
         )
 
         if runseqc:
-            run(execp="seqc_submit_mjobs.py", path=args["dockerizedSEQC"], **args)
+            out = run(execp="seqc_submit_mjobs.py", path=args["dockerizedSEQC"], **args)
 
-            for row in sample_data_.loc[
-                idx_seqc, ["id", "platform", "igo_id", "source", "s3uri"]
-            ].itertuples():
+            try:
+                assert out["returncode"] == 0, RuntimeError("SEQC run failed!".upper())
+                logging.info("SEQC run initiated successfully!")
+            except (AssertionError, RuntimeError) as e:
+                print("{:*^50}\n".format(" START ERROR "))
+                logging.error(out["stdout"])
+                logging.warning(str(e))
+                print()
+                print("{:*^50}\n".format(" END ERROR "))
+            else:
+                for row in sample_data_.loc[
+                    idx_seqc, ["id", "platform", "igo_id", "source", "s3uri"]
+                ].itertuples():
 
-                db_connect.cur.execute(q_raw, (row.id, row.platform, row.igo_id,))
-                rawData_id = [i[0] for i in db_connect.cur.fetchall()]
+                    db_connect.cur.execute(q_raw, (row.id, row.platform, row.igo_id,))
+                    rawData_id = [i[0] for i in db_connect.cur.fetchall()]
 
-                if rawData_id:
-                    db_connect.cur.execute(
-                        q_records, (rawData_id[0], tools_id, args["ami"]),
-                    )
-                    print("Update `run_records`:\n\t", db_connect.cur.statement)
+                    if rawData_id:
+                        db_connect.cur.execute(
+                            q_records, (rawData_id[0], tools_id, args["ami"]),
+                        )
+                        print("Update `run_records`:\n\t", db_connect.cur.statement)
 
             db_connect.db.commit()
 
@@ -309,22 +319,34 @@ def worker_main(
         )
 
         if atac:
-            run(execp="scata_submit_mjobs.py", path=atac_path, **args)
+            out = run(execp="scata_submit_mjobs.py", path=atac_path, **args)
 
-            for row in sample_data_.loc[
-                idx_atac, ["id", "platform", "igo_id", "source", "s3uri"]
-            ].itertuples():
+            try:
+                assert out["returncode"] == 0, RuntimeError(
+                    "scATAC-seq run failed!".upper()
+                )
+                logging.info("scATAC-seq run initiated successfully!")
+            except (AssertionError, RuntimeError) as e:
+                print("{:*^50}\n".format(" START ERROR "))
+                logging.error(out["stdout"])
+                logging.warning(str(e))
+                print()
+                print("{:*^50}\n".format(" END ERROR "))
+            else:
+                for row in sample_data_.loc[
+                    idx_atac, ["id", "platform", "igo_id", "source", "s3uri"]
+                ].itertuples():
 
-                db_connect.cur.execute(q_raw, (row.id, row.platform, row.igo_id,))
-                rawData_id = [i[0] for i in db_connect.cur.fetchall()]
+                    db_connect.cur.execute(q_raw, (row.id, row.platform, row.igo_id,))
+                    rawData_id = [i[0] for i in db_connect.cur.fetchall()]
 
-                if rawData_id:
-                    # TODO: workflow_id set for "ND" needs to be changed to a known id,
-                    #   e.g. ami-12345 or cromwel-${uuid}
-                    db_connect.cur.execute(
-                        q_records, (rawData_id[0], tools_id, "ND"),
-                    )
-                    print("Update `run_records`:\n\t", db_connect.cur.statement)
+                    if rawData_id:
+                        # TODO: workflow_id set for "ND" needs to be changed to a known
+                        #  id, e.g. ami-12345 or cromwel-${uuid}
+                        db_connect.cur.execute(
+                            q_records, (rawData_id[0], tools_id, "ND"),
+                        )
+                        print("Update `run_records`:\n\t", db_connect.cur.statement)
 
             db_connect.db.commit()
 
@@ -419,7 +441,10 @@ def worker_main(
 
                 except (TimeoutError, RuntimeError) as e:
                     db_connect.db.rollback()
+                    print("{:*^50}\n".format(" START ERROR "))
                     logging.error(str(e))
+                    print()
+                    print("{:*^50}\n".format(" END ERROR "))
 
                 db_connect.db.commit()
 
@@ -501,7 +526,10 @@ def worker_main(
 
                 except (TimeoutError, RuntimeError) as e:
                     db_connect.db.rollback()
+                    print("{:*^50}\n".format(" START ERROR "))
                     logging.error(str(e))
+                    print()
+                    print("{:*^50}\n".format(" END ERROR "))
 
                 db_connect.db.commit()
 
@@ -526,22 +554,34 @@ def worker_main(
         )
 
         if cr:
-            run(execp="sera_submit_mjobs.py", path=cellranger_path, **args)
+            out = run(execp="sera_submit_mjobs.py", path=cellranger_path, **args)
 
-            for row in sample_data_.loc[
-                idx_cellranger, ["id", "platform", "igo_id", "source", "s3uri"]
-            ].itertuples():
+            try:
+                assert out["returncode"] == 0, RuntimeError(
+                    "Cell Ranger run failed!".upper()
+                )
+                logging.info("Cell Ranger run initiated successfully!")
+            except (AssertionError, RuntimeError) as e:
+                print("{:*^50}\n".format(" START ERROR "))
+                logging.error(out["stdout"])
+                logging.warning(str(e))
+                print()
+                print("{:*^50}\n".format(" END ERROR "))
+            else:
+                for row in sample_data_.loc[
+                    idx_cellranger, ["id", "platform", "igo_id", "source", "s3uri"]
+                ].itertuples():
 
-                db_connect.cur.execute(q_raw, (row.id, row.platform, row.igo_id,))
-                rawData_id = [i[0] for i in db_connect.cur.fetchall()]
+                    db_connect.cur.execute(q_raw, (row.id, row.platform, row.igo_id,))
+                    rawData_id = [i[0] for i in db_connect.cur.fetchall()]
 
-                if rawData_id:
-                    # TODO: workflow_id set for "ND" needs to be changed to a known id,
-                    #   e.g. ami-12345 or cromwell-${uuid}
-                    db_connect.cur.execute(
-                        q_records, (rawData_id[0], tools_id, "ND"),
-                    )
-                    print("Update `run_records`:\n\t", db_connect.cur.statement)
+                    if rawData_id:
+                        # TODO: workflow_id set for "ND" needs to be changed to a known
+                        #  id, e.g. ami-12345 or cromwell-${uuid}
+                        db_connect.cur.execute(
+                            q_records, (rawData_id[0], tools_id, "ND"),
+                        )
+                        print("Update `run_records`:\n\t", db_connect.cur.statement)
 
             db_connect.db.commit()
 
